# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/trace/v2/http_tracer.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'envoy/config/trace/v2/http_tracer.proto\x12\x15\x65nvoy.config.trace.v2\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x01\n\x07Tracing\x12\x31\n\x04http\x18\x01 \x01(\x0b\x32#.envoy.config.trace.v2.Tracing.Http\x1a\x89\x01\n\x04Http\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_typeB\x86\x01\n#io.envoyproxy.envoy.config.trace.v2B\x0fHttpTracerProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v2.http_tracer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v2B\017HttpTracerProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v2;tracev2\272\200\310\321\006\002\020\001'
  _globals['_TRACING_HTTP'].fields_by_name['name']._options = None
  _globals['_TRACING_HTTP'].fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_TRACING_HTTP'].fields_by_name['config']._options = None
  _globals['_TRACING_HTTP'].fields_by_name['config']._serialized_options = b'\030\001'
  _globals['_TRACING']._serialized_start=180
  _globals['_TRACING']._serialized_end=380
  _globals['_TRACING_HTTP']._serialized_start=243
  _globals['_TRACING_HTTP']._serialized_end=380
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cds.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2

from envoy.api.v2.cluster_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/api/v2/cds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1a\x65nvoy/api/v2/cluster.proto\"\n\n\x08\x43\x64sDummy2\xe7\x02\n\x17\x43lusterDiscoveryService\x12W\n\x0eStreamClusters\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12`\n\rDeltaClusters\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12s\n\rFetchClusters\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v2/discovery:clusters:\x01*\x1a\x1c\x8a\xa4\x96\xf3\x07\x16\n\x14\x65nvoy.api.v2.ClusterB\x8b\x01\n\x1aio.envoyproxy.envoy.api.v2B\x08\x43\x64sProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.service.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\010CdsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\032\022\030envoy.service.cluster.v3\272\200\310\321\006\002\020\001'
  _globals['_CLUSTERDISCOVERYSERVICE']._options = None
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_options = b'\212\244\226\363\007\026\n\024envoy.api.v2.Cluster'
  _globals['_CLUSTERDISCOVERYSERVICE'].methods_by_name['FetchClusters']._options = None
  _globals['_CLUSTERDISCOVERYSERVICE'].methods_by_name['FetchClusters']._serialized_options = b'\202\323\344\223\002\033\"\026/v2/discovery:clusters:\001*'
  _globals['_CDSDUMMY']._serialized_start=225
  _globals['_CDSDUMMY']._serialized_end=235
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_start=238
  _globals['_CLUSTERDISCOVERYSERVICE']._serialized_end=597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/network/dns_resolver/getaddrinfo/v3/getaddrinfo_dns_resolver.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSenvoy/extensions/network/dns_resolver/getaddrinfo/v3/getaddrinfo_dns_resolver.proto\x12\x34\x65nvoy.extensions.network.dns_resolver.getaddrinfo.v3\x1a\x1dudpa/annotations/status.proto\"\x1e\n\x1cGetAddrInfoDnsResolverConfigB\xd6\x01\nBio.envoyproxy.envoy.extensions.network.dns_resolver.getaddrinfo.v3B\x1bGetaddrinfoDnsResolverProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/getaddrinfo/v3;getaddrinfov3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.network.dns_resolver.getaddrinfo.v3.getaddrinfo_dns_resolver_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nBio.envoyproxy.envoy.extensions.network.dns_resolver.getaddrinfo.v3B\033GetaddrinfoDnsResolverProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/network/dns_resolver/getaddrinfo/v3;getaddrinfov3\272\200\310\321\006\002\020\002'
  _globals['_GETADDRINFODNSRESOLVERCONFIG']._serialized_start=172
  _globals['_GETADDRINFODNSRESOLVERCONFIG']._serialized_end=202
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/annotations/v3/versioning.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#xds/annotations/v3/versioning.proto\x12\x12xds.annotations.v3\x1a google/protobuf/descriptor.proto\"5\n\x14VersioningAnnotation\x12\x1d\n\x15previous_message_type\x18\x01 \x01(\t:`\n\nversioning\x12\x1f.google.protobuf.MessageOptions\x18\x93\xfd\x86, \x01(\x0b\x32(.xds.annotations.v3.VersioningAnnotationB+Z)github.com/cncf/xds/go/xds/annotations/v3b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.annotations.v3.versioning_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cncf/xds/go/xds/annotations/v3'
  _globals['_VERSIONINGANNOTATION']._serialized_start=93
  _globals['_VERSIONINGANNOTATION']._serialized_end=146
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/buffer/v2/buffer.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/filter/http/buffer/v2/buffer.proto\x12\"envoy.config.filter.http.buffer.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"U\n\x06\x42uffer\x12\x45\n\x11max_request_bytes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x02 \x00\x8a\x01\x02\x10\x01J\x04\x08\x02\x10\x03\"\x86\x01\n\x0e\x42ufferPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12\x46\n\x06\x62uffer\x18\x02 \x01(\x0b\x32*.envoy.config.filter.http.buffer.v2.BufferB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\x42\xcc\x01\n0io.envoyproxy.envoy.config.filter.http.buffer.v2B\x0b\x42ufferProtoP\x01ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/buffer/v2;bufferv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.filters.http.buffer.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.buffer.v2.buffer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0io.envoyproxy.envoy.config.filter.http.buffer.v2B\013BufferProtoP\001ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/buffer/v2;bufferv2\362\230\376\217\005)\022\'envoy.extensions.filters.http.buffer.v3\272\200\310\321\006\002\020\001'
  _globals['_BUFFER'].fields_by_name['max_request_bytes']._options = None
  _globals['_BUFFER'].fields_by_name['max_request_bytes']._serialized_options = b'\372B\t*\002 \000\212\001\002\020\001'
  _globals['_BUFFERPERROUTE'].oneofs_by_name['override']._options = None
  _globals['_BUFFERPERROUTE'].oneofs_by_name['override']._serialized_options = b'\370B\001'
  _globals['_BUFFERPERROUTE'].fields_by_name['disabled']._options = None
  _globals['_BUFFERPERROUTE'].fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _globals['_BUFFERPERROUTE'].fields_by_name['buffer']._options = None
  _globals['_BUFFERPERROUTE'].fields_by_name['buffer']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_BUFFER']._serialized_start=207
  _globals['_BUFFER']._serialized_end=292
  _globals['_BUFFERPERROUTE']._serialized_start=295
  _globals['_BUFFERPERROUTE']._serialized_end=429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/migrate.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eudpa/annotations/migrate.proto\x12\x10udpa.annotations\x1a google/protobuf/descriptor.proto\"#\n\x11MigrateAnnotation\x12\x0e\n\x06rename\x18\x01 \x01(\t\"A\n\x16\x46ieldMigrateAnnotation\x12\x0e\n\x06rename\x18\x01 \x01(\t\x12\x17\n\x0foneof_promotion\x18\x02 \x01(\t\"0\n\x15\x46ileMigrateAnnotation\x12\x17\n\x0fmove_to_package\x18\x02 \x01(\t:`\n\x0fmessage_migrate\x12\x1f.google.protobuf.MessageOptions\x18\x8e\xe3\xffQ \x01(\x0b\x32#.udpa.annotations.MigrateAnnotation:a\n\rfield_migrate\x12\x1d.google.protobuf.FieldOptions\x18\x8e\xe3\xffQ \x01(\x0b\x32(.udpa.annotations.FieldMigrateAnnotation:Z\n\x0c\x65num_migrate\x12\x1c.google.protobuf.EnumOptions\x18\x8e\xe3\xffQ \x01(\x0b\x32#.udpa.annotations.MigrateAnnotation:e\n\x12\x65num_value_migrate\x12!.google.protobuf.EnumValueOptions\x18\x8e\xe3\xffQ \x01(\x0b\x32#.udpa.annotations.MigrateAnnotation:^\n\x0c\x66ile_migrate\x12\x1c.google.protobuf.FileOptions\x18\x8e\xe3\xffQ \x01(\x0b\x32\'.udpa.annotations.FileMigrateAnnotationB$Z\"github.com/cncf/xds/go/annotationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'udpa.annotations.migrate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\"github.com/cncf/xds/go/annotations'
  _globals['_MIGRATEANNOTATION']._serialized_start=86
  _globals['_MIGRATEANNOTATION']._serialized_end=121
  _globals['_FIELDMIGRATEANNOTATION']._serialized_start=123
  _globals['_FIELDMIGRATEANNOTATION']._serialized_end=188
  _globals['_FILEMIGRATEANNOTATION']._serialized_start=190
  _globals['_FILEMIGRATEANNOTATION']._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/resource_monitor/injected_resource/v2alpha/injected_resource.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOenvoy/config/resource_monitor/injected_resource/v2alpha/injected_resource.proto\x12\x37\x65nvoy.config.resource_monitor.injected_resource.v2alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"3\n\x16InjectedResourceConfig\x12\x19\n\x08\x66ilename\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x42\xc8\x01\nEio.envoyproxy.envoy.config.resource_monitor.injected_resource.v2alphaB\x15InjectedResourceProtoP\x01Z^github.com/envoyproxy/go-control-plane/envoy/config/resource_monitor/injected_resource/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.resource_monitor.injected_resource.v2alpha.injected_resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nEio.envoyproxy.envoy.config.resource_monitor.injected_resource.v2alphaB\025InjectedResourceProtoP\001Z^github.com/envoyproxy/go-control-plane/envoy/config/resource_monitor/injected_resource/v2alpha\272\200\310\321\006\002\020\002'
  _globals['_INJECTEDRESOURCECONFIG'].fields_by_name['filename']._options = None
  _globals['_INJECTEDRESOURCECONFIG'].fields_by_name['filename']._serialized_options = b'\372B\004r\002 \001'
  _globals['_INJECTEDRESOURCECONFIG']._serialized_start=196
  _globals['_INJECTEDRESOURCECONFIG']._serialized_end=247
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/pick_first/v3/pick_first.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/load_balancing_policies/pick_first/v3/pick_first.proto\x12\x36\x65nvoy.extensions.load_balancing_policies.pick_first.v3\x1a\x1dudpa/annotations/status.proto\")\n\tPickFirst\x12\x1c\n\x14shuffle_address_list\x18\x01 \x01(\x08\x42\xcc\x01\nDio.envoyproxy.envoy.extensions.load_balancing_policies.pick_first.v3B\x0ePickFirstProtoP\x01Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/pick_first/v3;pick_firstv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.pick_first.v3.pick_first_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nDio.envoyproxy.envoy.extensions.load_balancing_policies.pick_first.v3B\016PickFirstProtoP\001Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/pick_first/v3;pick_firstv3\272\200\310\321\006\002\020\002'
  _globals['_PICKFIRST']._serialized_start=162
  _globals['_PICKFIRST']._serialized_end=203
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/stream/v3/stream.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/extensions/access_loggers/stream/v3/stream.proto\x12)envoy.extensions.access_loggers.stream.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"v\n\x0fStdoutAccessLog\x12N\n\nlog_format\x18\x01 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x13\n\x11\x61\x63\x63\x65ss_log_format\"v\n\x0fStderrAccessLog\x12N\n\nlog_format\x18\x01 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x42\x13\n\x11\x61\x63\x63\x65ss_log_formatB\xab\x01\n7io.envoyproxy.envoy.extensions.access_loggers.stream.v3B\x0bStreamProtoP\x01ZYgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/stream/v3;streamv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.stream.v3.stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.extensions.access_loggers.stream.v3B\013StreamProtoP\001ZYgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/stream/v3;streamv3\272\200\310\321\006\002\020\002'
  _globals['_STDOUTACCESSLOG'].fields_by_name['log_format']._options = None
  _globals['_STDOUTACCESSLOG'].fields_by_name['log_format']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STDERRACCESSLOG'].fields_by_name['log_format']._options = None
  _globals['_STDERRACCESSLOG'].fields_by_name['log_format']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STDOUTACCESSLOG']._serialized_start=212
  _globals['_STDOUTACCESSLOG']._serialized_end=330
  _globals['_STDERRACCESSLOG']._serialized_start=332
  _globals['_STDERRACCESSLOG']._serialized_end=450
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/retry/host/omit_host_metadata/v3/omit_host_metadata_config.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQenvoy/extensions/retry/host/omit_host_metadata/v3/omit_host_metadata_config.proto\x12\x31\x65nvoy.extensions.retry.host.omit_host_metadata.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x98\x01\n\x16OmitHostMetadataConfig\x12\x36\n\x0emetadata_match\x18\x01 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata:F\x9a\xc5\x88\x1e\x41\n?envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfigB\xd7\x01\n?io.envoyproxy.envoy.extensions.retry.host.omit_host_metadata.v3B\x1bOmitHostMetadataConfigProtoP\x01Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/host/omit_host_metadata/v3;omit_host_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.retry.host.omit_host_metadata.v3.omit_host_metadata_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n?io.envoyproxy.envoy.extensions.retry.host.omit_host_metadata.v3B\033OmitHostMetadataConfigProtoP\001Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/retry/host/omit_host_metadata/v3;omit_host_metadatav3\272\200\310\321\006\002\020\002'
  _globals['_OMITHOSTMETADATACONFIG']._options = None
  _globals['_OMITHOSTMETADATACONFIG']._serialized_options = b'\232\305\210\036A\n?envoy.config.retry.omit_host_metadata.v2.OmitHostMetadataConfig'
  _globals['_OMITHOSTMETADATACONFIG']._serialized_start=236
  _globals['_OMITHOSTMETADATACONFIG']._serialized_end=388
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/brotli/decompressor/v3/brotli.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/compression/brotli/decompressor/v3/brotli.proto\x12\x33\x65nvoy.extensions.compression.brotli.decompressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"r\n\x06\x42rotli\x12(\n disable_ring_buffer_reallocation\x18\x01 \x01(\x08\x12>\n\nchunk_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 B\xc5\x01\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\x0b\x42rotliProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/brotli/decompressor/v3;decompressorv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.compression.brotli.decompressor.v3.brotli_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nAio.envoyproxy.envoy.extensions.compression.brotli.decompressor.v3B\013BrotliProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/compression/brotli/decompressor/v3;decompressorv3\272\200\310\321\006\002\020\002'
  _globals['_BROTLI'].fields_by_name['chunk_size']._options = None
  _globals['_BROTLI'].fields_by_name['chunk_size']._serialized_options = b'\372B\t*\007\030\200\200\004(\200 '
  _globals['_BROTLI']._serialized_start=209
  _globals['_BROTLI']._serialized_end=323
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/decimal.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19google/type/decimal.proto\x12\x0bgoogle.type\"\x18\n\x07\x44\x65\x63imal\x12\r\n\x05value\x18\x01 \x01(\tBf\n\x0f\x63om.google.typeB\x0c\x44\x65\x63imalProtoP\x01Z:google.golang.org/genproto/googleapis/type/decimal;decimal\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.decimal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\014DecimalProtoP\001Z:google.golang.org/genproto/googleapis/type/decimal;decimal\370\001\001\242\002\003GTP'
  _globals['_DECIMAL']._serialized_start=42
  _globals['_DECIMAL']._serialized_end=66
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/metrics/v3/stats.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/metrics/v3/stats.proto\x12\x17\x65nvoy.config.metrics.v3\x1a\"envoy/config/core/v3/address.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8e\x01\n\tStatsSink\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:(\x9a\xc5\x88\x1e#\n!envoy.config.metrics.v2.StatsSinkB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xc1\x02\n\x0bStatsConfig\x12\x39\n\nstats_tags\x18\x01 \x03(\x0b\x32%.envoy.config.metrics.v3.TagSpecifier\x12\x38\n\x14use_all_default_tags\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\rstats_matcher\x18\x03 \x01(\x0b\x32%.envoy.config.metrics.v3.StatsMatcher\x12S\n\x19histogram_bucket_settings\x18\x04 \x03(\x0b\x32\x30.envoy.config.metrics.v3.HistogramBucketSettings:*\x9a\xc5\x88\x1e%\n#envoy.config.metrics.v2.StatsConfig\"\xef\x01\n\x0cStatsMatcher\x12\x14\n\nreject_all\x18\x01 \x01(\x08H\x00\x12\x42\n\x0e\x65xclusion_list\x18\x02 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcherH\x00\x12\x42\n\x0einclusion_list\x18\x03 \x01(\x0b\x32(.envoy.type.matcher.v3.ListStringMatcherH\x00:+\x9a\xc5\x88\x1e&\n$envoy.config.metrics.v2.StatsMatcherB\x14\n\rstats_matcher\x12\x03\xf8\x42\x01\"\x8c\x01\n\x0cTagSpecifier\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x19\n\x05regex\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03(\x80\x08H\x00\x12\x15\n\x0b\x66ixed_value\x18\x03 \x01(\tH\x00:+\x9a\xc5\x88\x1e&\n$envoy.config.metrics.v2.TagSpecifierB\x0b\n\ttag_value\"\x82\x01\n\x17HistogramBucketSettings\x12=\n\x05match\x18\x01 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x07\x62uckets\x18\x02 \x03(\x01\x42\x17\xfa\x42\x14\x92\x01\x11\x08\x01\x18\x01\"\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00\"\xae\x01\n\nStatsdSink\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.AddressH\x00\x12\x1a\n\x10tcp_cluster_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\t:)\x9a\xc5\x88\x1e$\n\"envoy.config.metrics.v2.StatsdSinkB\x17\n\x10statsd_specifier\x12\x03\xf8\x42\x01\"\xe9\x01\n\rDogStatsdSink\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1d.envoy.config.core.v3.AddressH\x00\x12\x0e\n\x06prefix\x18\x03 \x01(\t\x12\x45\n\x16max_bytes_per_datagram\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueB\x07\xfa\x42\x04\x32\x02 \x00:,\x9a\xc5\x88\x1e\'\n%envoy.config.metrics.v2.DogStatsdSinkB\x1b\n\x14\x64og_statsd_specifier\x12\x03\xf8\x42\x01J\x04\x08\x02\x10\x03\"N\n\x0bHystrixSink\x12\x13\n\x0bnum_buckets\x18\x01 \x01(\x03:*\x9a\xc5\x88\x1e%\n#envoy.config.metrics.v2.HystrixSinkB\x87\x01\n%io.envoyproxy.envoy.config.metrics.v3B\nStatsProtoP\x01ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v3;metricsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.metrics.v3.stats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%io.envoyproxy.envoy.config.metrics.v3B\nStatsProtoP\001ZHgithub.com/envoyproxy/go-control-plane/envoy/config/metrics/v3;metricsv3\272\200\310\321\006\002\020\002'
  _globals['_STATSSINK']._options = None
  _globals['_STATSSINK']._serialized_options = b'\232\305\210\036#\n!envoy.config.metrics.v2.StatsSink'
  _globals['_STATSCONFIG']._options = None
  _globals['_STATSCONFIG']._serialized_options = b'\232\305\210\036%\n#envoy.config.metrics.v2.StatsConfig'
  _globals['_STATSMATCHER'].oneofs_by_name['stats_matcher']._options = None
  _globals['_STATSMATCHER'].oneofs_by_name['stats_matcher']._serialized_options = b'\370B\001'
  _globals['_STATSMATCHER']._options = None
  _globals['_STATSMATCHER']._serialized_options = b'\232\305\210\036&\n$envoy.config.metrics.v2.StatsMatcher'
  _globals['_TAGSPECIFIER'].fields_by_name['regex']._options = None
  _globals['_TAGSPECIFIER'].fields_by_name['regex']._serialized_options = b'\372B\005r\003(\200\010'
  _globals['_TAGSPECIFIER']._options = None
  _globals['_TAGSPECIFIER']._serialized_options = b'\232\305\210\036&\n$envoy.config.metrics.v2.TagSpecifier'
  _globals['_HISTOGRAMBUCKETSETTINGS'].fields_by_name['match']._options = None
  _globals['_HISTOGRAMBUCKETSETTINGS'].fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_HISTOGRAMBUCKETSETTINGS'].fields_by_name['buckets']._options = None
  _globals['_HISTOGRAMBUCKETSETTINGS'].fields_by_name['buckets']._serialized_options = b'\372B\024\222\001\021\010\001\030\001\"\013\022\t!\000\000\000\000\000\000\000\000'
  _globals['_STATSDSINK'].oneofs_by_name['statsd_specifier']._options = None
  _globals['_STATSDSINK'].oneofs_by_name['statsd_specifier']._serialized_options = b'\370B\001'
  _globals['_STATSDSINK']._options = None
  _globals['_STATSDSINK']._serialized_options = b'\232\305\210\036$\n\"envoy.config.metrics.v2.StatsdSink'
  _globals['_DOGSTATSDSINK'].oneofs_by_name['dog_statsd_specifier']._options = None
  _globals['_DOGSTATSDSINK'].oneofs_by_name['dog_statsd_specifier']._serialized_options = b'\370B\001'
  _globals['_DOGSTATSDSINK'].fields_by_name['max_bytes_per_datagram']._options = None
  _globals['_DOGSTATSDSINK'].fields_by_name['max_bytes_per_datagram']._serialized_options = b'\372B\0042\002 \000'
  _globals['_DOGSTATSDSINK']._options = None
  _globals['_DOGSTATSDSINK']._serialized_options = b'\232\305\210\036\'\n%envoy.config.metrics.v2.DogStatsdSink'
  _globals['_HYSTRIXSINK']._options = None
  _globals['_HYSTRIXSINK']._serialized_options = b'\232\305\210\036%\n#envoy.config.metrics.v2.HystrixSink'
  _globals['_STATSSINK']._serialized_start=287
  _globals['_STATSSINK']._serialized_end=429
  _globals['_STATSCONFIG']._serialized_start=432
  _globals['_STATSCONFIG']._serialized_end=753
  _globals['_STATSMATCHER']._serialized_start=756
  _globals['_STATSMATCHER']._serialized_end=995
  _globals['_TAGSPECIFIER']._serialized_start=998
  _globals['_TAGSPECIFIER']._serialized_end=1138
  _globals['_HISTOGRAMBUCKETSETTINGS']._serialized_start=1141
  _globals['_HISTOGRAMBUCKETSETTINGS']._serialized_end=1271
  _globals['_STATSDSINK']._serialized_start=1274
  _globals['_STATSDSINK']._serialized_end=1448
  _globals['_DOGSTATSDSINK']._serialized_start=1451
  _globals['_DOGSTATSDSINK']._serialized_end=1684
  _globals['_HYSTRIXSINK']._serialized_start=1686
  _globals['_HYSTRIXSINK']._serialized_end=1764
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/log.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import label_pb2 as google_dot_api_dot_label__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14google/api/log.proto\x12\ngoogle.api\x1a\x16google/api/label.proto\"u\n\rLogDescriptor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\x06labels\x18\x02 \x03(\x0b\x32\x1b.google.api.LabelDescriptor\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\tBj\n\x0e\x63om.google.apiB\x08LogProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.log_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\010LogProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_LOGDESCRIPTOR']._serialized_start=60
  _globals['_LOGDESCRIPTOR']._serialized_end=177
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/dubbo/router/v2alpha1/router.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/config/filter/dubbo/router/v2alpha1/router.proto\x12)envoy.config.filter.dubbo.router.v2alpha1\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x08\n\x06RouterB\xe0\x01\n7io.envoyproxy.envoy.config.filter.dubbo.router.v2alpha1B\x0bRouterProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/dubbo/router/v2alpha1\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.filters.network.dubbo_proxy.router.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.dubbo.router.v2alpha1.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7io.envoyproxy.envoy.config.filter.dubbo.router.v2alpha1B\013RouterProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/config/filter/dubbo/router/v2alpha1\362\230\376\217\0058\0226envoy.extensions.filters.network.dubbo_proxy.router.v3\272\200\310\321\006\002\020\001'
  _globals['_ROUTER']._serialized_start=164
  _globals['_ROUTER']._serialized_end=172
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/endpoint/endpoint.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.endpoint import endpoint_components_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2

from envoy.api.v2.endpoint.endpoint_components_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/endpoint/endpoint.proto\x12\x15\x65nvoy.api.v2.endpoint\x1a/envoy/api/v2/endpoint/endpoint_components.protoBt\n#io.envoyproxy.envoy.api.v2.endpointB\rEndpointProtoP\x01Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpointP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.endpoint.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.api.v2.endpointB\rEndpointProtoP\001Z<github.com/envoyproxy/go-control-plane/envoy/api/v2/endpoint'
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/load_balancing_policies/cluster_provided/v3/cluster_provided.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSenvoy/extensions/load_balancing_policies/cluster_provided/v3/cluster_provided.proto\x12<envoy.extensions.load_balancing_policies.cluster_provided.v3\x1a\x1dudpa/annotations/status.proto\"\x11\n\x0f\x43lusterProvidedB\xe4\x01\nJio.envoyproxy.envoy.extensions.load_balancing_policies.cluster_provided.v3B\x14\x43lusterProvidedProtoP\x01Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/cluster_provided/v3;cluster_providedv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.load_balancing_policies.cluster_provided.v3.cluster_provided_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nJio.envoyproxy.envoy.extensions.load_balancing_policies.cluster_provided.v3B\024ClusterProvidedProtoP\001Zvgithub.com/envoyproxy/go-control-plane/envoy/extensions/load_balancing_policies/cluster_provided/v3;cluster_providedv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERPROVIDED']._serialized_start=180
  _globals['_CLUSTERPROVIDED']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/context.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18google/api/context.proto\x12\ngoogle.api\"1\n\x07\x43ontext\x12&\n\x05rules\x18\x01 \x03(\x0b\x32\x17.google.api.ContextRule\"\x8d\x01\n\x0b\x43ontextRule\x12\x10\n\x08selector\x18\x01 \x01(\t\x12\x11\n\trequested\x18\x02 \x03(\t\x12\x10\n\x08provided\x18\x03 \x03(\t\x12\"\n\x1a\x61llowed_request_extensions\x18\x04 \x03(\t\x12#\n\x1b\x61llowed_response_extensions\x18\x05 \x03(\tBn\n\x0e\x63om.google.apiB\x0c\x43ontextProtoP\x01ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\xa2\x02\x04GAPIb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.context_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.google.apiB\014ContextProtoP\001ZEgoogle.golang.org/genproto/googleapis/api/serviceconfig;serviceconfig\242\002\004GAPI'
  _globals['_CONTEXT']._serialized_start=40
  _globals['_CONTEXT']._serialized_end=89
  _globals['_CONTEXTRULE']._serialized_start=92
  _globals['_CONTEXTRULE']._serialized_end=233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ratelimit/v3/rate_limit.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.ratelimit.v3 import rls_pb2 as envoy_dot_config_dot_ratelimit_dot_v3_dot_rls__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.metadata.v3 import metadata_pb2 as envoy_dot_type_dot_metadata_dot_v3_dot_metadata__pb2
from envoy.type.v3 import http_status_pb2 as envoy_dot_type_dot_v3_dot_http__status__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/filters/http/ratelimit/v3/rate_limit.proto\x12*envoy.extensions.filters.http.ratelimit.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/ratelimit/v3/rls.proto\x1a,envoy/config/route/v3/route_components.proto\x1a%envoy/type/metadata/v3/metadata.proto\x1a\x1f\x65nvoy/type/v3/http_status.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf1\x05\n\tRateLimit\x12\x17\n\x06\x64omain\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05stage\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x37\n\x0crequest_type\x18\x03 \x01(\tB!\xfa\x42\x1er\x1cR\x08internalR\x08\x65xternalR\x04\x62othR\x00\x12*\n\x07timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x66\x61ilure_mode_deny\x18\x05 \x01(\x08\x12*\n\"rate_limited_as_resource_exhausted\x18\x06 \x01(\x08\x12W\n\x12rate_limit_service\x18\x07 \x01(\x0b\x32\x31.envoy.config.ratelimit.v3.RateLimitServiceConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x7f\n\x1a\x65nable_x_ratelimit_headers\x18\x08 \x01(\x0e\x32Q.envoy.extensions.filters.http.ratelimit.v3.RateLimit.XRateLimitHeadersRFCVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12*\n\"disable_x_envoy_ratelimited_header\x18\t \x01(\x08\x12\x36\n\x13rate_limited_status\x18\n \x01(\x0b\x32\x19.envoy.type.v3.HttpStatus\x12R\n\x17response_headers_to_add\x18\x0b \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\x08\xfa\x42\x05\x92\x01\x02\x10\n\"<\n\x1bXRateLimitHeadersRFCVersion\x12\x07\n\x03OFF\x10\x00\x12\x14\n\x10\x44RAFT_VERSION_03\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.http.rate_limit.v2.RateLimit\"\xf6\x0f\n\x0fRateLimitConfig\x12\x16\n\x05stage\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\n\x12\x13\n\x0b\x64isable_key\x18\x02 \x01(\t\x12]\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x42.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.ActionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12S\n\x05limit\x18\x04 \x01(\x0b\x32\x44.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Override\x1a\x8f\x0c\n\x06\x41\x63tion\x12j\n\x0esource_cluster\x18\x01 \x01(\x0b\x32P.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.SourceClusterH\x00\x12t\n\x13\x64\x65stination_cluster\x18\x02 \x01(\x0b\x32U.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.DestinationClusterH\x00\x12l\n\x0frequest_headers\x18\x03 \x01(\x0b\x32Q.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.RequestHeadersH\x00\x12j\n\x0eremote_address\x18\x04 \x01(\x0b\x32P.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.RemoteAddressH\x00\x12\x64\n\x0bgeneric_key\x18\x05 \x01(\x0b\x32M.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.GenericKeyH\x00\x12q\n\x12header_value_match\x18\x06 \x01(\x0b\x32S.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.HeaderValueMatchH\x00\x12_\n\x08metadata\x18\x08 \x01(\x0b\x32K.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.MetaDataH\x00\x12?\n\textension\x18\t \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigH\x00\x1a\x0f\n\rSourceCluster\x1a\x14\n\x12\x44\x65stinationCluster\x1am\n\x0eRequestHeaders\x12\"\n\x0bheader_name\x18\x01 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x01\xc8\x01\x00\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0eskip_if_absent\x18\x03 \x01(\x08\x1a\x0f\n\rRemoteAddress\x1aG\n\nGenericKey\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x0e\x64\x65scriptor_key\x18\x02 \x01(\t\x1a\x8c\x01\n\x10HeaderValueMatch\x12!\n\x10\x64\x65scriptor_value\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x0c\x65xpect_match\x18\x02 \x01(\x08\x12?\n\x07headers\x18\x03 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcherB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb5\x02\n\x08MetaData\x12\x1f\n\x0e\x64\x65scriptor_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x43\n\x0cmetadata_key\x18\x02 \x01(\x0b\x32#.envoy.type.metadata.v3.MetadataKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x15\n\rdefault_value\x18\x03 \x01(\t\x12l\n\x06source\x18\x04 \x01(\x0e\x32R.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Action.MetaData.SourceB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x16\n\x0eskip_if_absent\x18\x05 \x01(\x08\"&\n\x06Source\x12\x0b\n\x07\x44YNAMIC\x10\x00\x12\x0f\n\x0bROUTE_ENTRY\x10\x01\x42\x17\n\x10\x61\x63tion_specifier\x12\x03\xf8\x42\x01\x1a\xef\x01\n\x08Override\x12p\n\x10\x64ynamic_metadata\x18\x01 \x01(\x0b\x32T.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig.Override.DynamicMetadataH\x00\x1aV\n\x0f\x44ynamicMetadata\x12\x43\n\x0cmetadata_key\x18\x01 \x01(\x0b\x32#.envoy.type.metadata.v3.MetadataKeyB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42\x19\n\x12override_specifier\x12\x03\xf8\x42\x01\"\xf6\x03\n\x11RateLimitPerRoute\x12s\n\x0evh_rate_limits\x18\x01 \x01(\x0e\x32Q.envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute.VhRateLimitsOptionsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12p\n\x0foverride_option\x18\x02 \x01(\x0e\x32M.envoy.extensions.filters.http.ratelimit.v3.RateLimitPerRoute.OverrideOptionsB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12P\n\x0brate_limits\x18\x03 \x03(\x0b\x32;.envoy.extensions.filters.http.ratelimit.v3.RateLimitConfig\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\"<\n\x13VhRateLimitsOptions\x12\x0c\n\x08OVERRIDE\x10\x00\x12\x0b\n\x07INCLUDE\x10\x01\x12\n\n\x06IGNORE\x10\x02\"Z\n\x0fOverrideOptions\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x13\n\x0fOVERRIDE_POLICY\x10\x01\x12\x12\n\x0eINCLUDE_POLICY\x10\x02\x12\x11\n\rIGNORE_POLICY\x10\x03\x42\xb3\x01\n8io.envoyproxy.envoy.extensions.filters.http.ratelimit.v3B\x0eRateLimitProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ratelimit/v3;ratelimitv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.ratelimit.v3.rate_limit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.http.ratelimit.v3B\016RateLimitProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/ratelimit/v3;ratelimitv3\272\200\310\321\006\002\020\002'
  _globals['_RATELIMIT'].fields_by_name['domain']._options = None
  _globals['_RATELIMIT'].fields_by_name['domain']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RATELIMIT'].fields_by_name['stage']._options = None
  _globals['_RATELIMIT'].fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _globals['_RATELIMIT'].fields_by_name['request_type']._options = None
  _globals['_RATELIMIT'].fields_by_name['request_type']._serialized_options = b'\372B\036r\034R\010internalR\010externalR\004bothR\000'
  _globals['_RATELIMIT'].fields_by_name['rate_limit_service']._options = None
  _globals['_RATELIMIT'].fields_by_name['rate_limit_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_RATELIMIT'].fields_by_name['enable_x_ratelimit_headers']._options = None
  _globals['_RATELIMIT'].fields_by_name['enable_x_ratelimit_headers']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RATELIMIT'].fields_by_name['response_headers_to_add']._options = None
  _globals['_RATELIMIT'].fields_by_name['response_headers_to_add']._serialized_options = b'\372B\005\222\001\002\020\n'
  _globals['_RATELIMIT']._options = None
  _globals['_RATELIMIT']._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.http.rate_limit.v2.RateLimit'
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS'].fields_by_name['header_name']._options = None
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS'].fields_by_name['header_name']._serialized_options = b'\372B\nr\010\020\001\300\001\001\310\001\000'
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS'].fields_by_name['descriptor_key']._options = None
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS'].fields_by_name['descriptor_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION_GENERICKEY'].fields_by_name['descriptor_value']._options = None
  _globals['_RATELIMITCONFIG_ACTION_GENERICKEY'].fields_by_name['descriptor_value']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH'].fields_by_name['descriptor_value']._options = None
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH'].fields_by_name['descriptor_value']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH'].fields_by_name['headers']._options = None
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH'].fields_by_name['headers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['descriptor_key']._options = None
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['descriptor_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['metadata_key']._options = None
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['metadata_key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['source']._options = None
  _globals['_RATELIMITCONFIG_ACTION_METADATA'].fields_by_name['source']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RATELIMITCONFIG_ACTION'].oneofs_by_name['action_specifier']._options = None
  _globals['_RATELIMITCONFIG_ACTION'].oneofs_by_name['action_specifier']._serialized_options = b'\370B\001'
  _globals['_RATELIMITCONFIG_OVERRIDE_DYNAMICMETADATA'].fields_by_name['metadata_key']._options = None
  _globals['_RATELIMITCONFIG_OVERRIDE_DYNAMICMETADATA'].fields_by_name['metadata_key']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_RATELIMITCONFIG_OVERRIDE'].oneofs_by_name['override_specifier']._options = None
  _globals['_RATELIMITCONFIG_OVERRIDE'].oneofs_by_name['override_specifier']._serialized_options = b'\370B\001'
  _globals['_RATELIMITCONFIG'].fields_by_name['stage']._options = None
  _globals['_RATELIMITCONFIG'].fields_by_name['stage']._serialized_options = b'\372B\004*\002\030\n'
  _globals['_RATELIMITCONFIG'].fields_by_name['actions']._options = None
  _globals['_RATELIMITCONFIG'].fields_by_name['actions']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_RATELIMITPERROUTE'].fields_by_name['vh_rate_limits']._options = None
  _globals['_RATELIMITPERROUTE'].fields_by_name['vh_rate_limits']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RATELIMITPERROUTE'].fields_by_name['override_option']._options = None
  _globals['_RATELIMITPERROUTE'].fields_by_name['override_option']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_RATELIMIT']._serialized_start=457
  _globals['_RATELIMIT']._serialized_end=1210
  _globals['_RATELIMIT_XRATELIMITHEADERSRFCVERSION']._serialized_start=1093
  _globals['_RATELIMIT_XRATELIMITHEADERSRFCVERSION']._serialized_end=1153
  _globals['_RATELIMITCONFIG']._serialized_start=1213
  _globals['_RATELIMITCONFIG']._serialized_end=3251
  _globals['_RATELIMITCONFIG_ACTION']._serialized_start=1458
  _globals['_RATELIMITCONFIG_ACTION']._serialized_end=3009
  _globals['_RATELIMITCONFIG_ACTION_SOURCECLUSTER']._serialized_start=2291
  _globals['_RATELIMITCONFIG_ACTION_SOURCECLUSTER']._serialized_end=2306
  _globals['_RATELIMITCONFIG_ACTION_DESTINATIONCLUSTER']._serialized_start=2308
  _globals['_RATELIMITCONFIG_ACTION_DESTINATIONCLUSTER']._serialized_end=2328
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS']._serialized_start=2330
  _globals['_RATELIMITCONFIG_ACTION_REQUESTHEADERS']._serialized_end=2439
  _globals['_RATELIMITCONFIG_ACTION_REMOTEADDRESS']._serialized_start=2441
  _globals['_RATELIMITCONFIG_ACTION_REMOTEADDRESS']._serialized_end=2456
  _globals['_RATELIMITCONFIG_ACTION_GENERICKEY']._serialized_start=2458
  _globals['_RATELIMITCONFIG_ACTION_GENERICKEY']._serialized_end=2529
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH']._serialized_start=2532
  _globals['_RATELIMITCONFIG_ACTION_HEADERVALUEMATCH']._serialized_end=2672
  _globals['_RATELIMITCONFIG_ACTION_METADATA']._serialized_start=2675
  _globals['_RATELIMITCONFIG_ACTION_METADATA']._serialized_end=2984
  _globals['_RATELIMITCONFIG_ACTION_METADATA_SOURCE']._serialized_start=2946
  _globals['_RATELIMITCONFIG_ACTION_METADATA_SOURCE']._serialized_end=2984
  _globals['_RATELIMITCONFIG_OVERRIDE']._serialized_start=3012
  _globals['_RATELIMITCONFIG_OVERRIDE']._serialized_end=3251
  _globals['_RATELIMITCONFIG_OVERRIDE_DYNAMICMETADATA']._serialized_start=3138
  _globals['_RATELIMITCONFIG_OVERRIDE_DYNAMICMETADATA']._serialized_end=3224
  _globals['_RATELIMITPERROUTE']._serialized_start=3254
  _globals['_RATELIMITPERROUTE']._serialized_end=3756
  _globals['_RATELIMITPERROUTE_VHRATELIMITSOPTIONS']._serialized_start=3604
  _globals['_RATELIMITPERROUTE_VHRATELIMITSOPTIONS']._serialized_end=3664
  _globals['_RATELIMITPERROUTE_OVERRIDEOPTIONS']._serialized_start=3666
  _globals['_RATELIMITPERROUTE_OVERRIDEOPTIONS']._serialized_end=3756
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_protocol__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nZenvoy/extensions/filters/http/alternate_protocols_cache/v3/alternate_protocols_cache.proto\x12:envoy.extensions.filters.http.alternate_protocols_cache.v3\x1a#envoy/config/core/v3/protocol.proto\x1a\x1dudpa/annotations/status.proto\"o\n\x0c\x46ilterConfig\x12_\n!alternate_protocols_cache_options\x18\x01 \x01(\x0b\x32\x34.envoy.config.core.v3.AlternateProtocolsCacheOptionsB\xf1\x01\nHio.envoyproxy.envoy.extensions.filters.http.alternate_protocols_cache.v3B\x1c\x41lternateProtocolsCacheProtoP\x01Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/alternate_protocols_cache/v3;alternate_protocols_cachev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.alternate_protocols_cache.v3.alternate_protocols_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nHio.envoyproxy.envoy.extensions.filters.http.alternate_protocols_cache.v3B\034AlternateProtocolsCacheProtoP\001Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/alternate_protocols_cache/v3;alternate_protocols_cachev3\272\200\310\321\006\002\020\002'
  _globals['_FILTERCONFIG']._serialized_start=222
  _globals['_FILTERCONFIG']._serialized_end=333
# @@protoc_insertion_point(module_scope)
